@@ -31,8 +31,8 @@ class TestSuiteChromosomeFactory(
     def get_chromosome(self) -> tsc.TestSuiteChromosome:
         chromosome = tsc.TestSuiteChromosome(self.test_case_chromosome_factory)
         num_tests = randomness.next_int(
-            config.configuration.min_initial_tests,
-            config.configuration.max_initial_tests + 1,
+            config.configuration.search_algorithm.min_initial_tests,
+            config.configuration.search_algorithm.max_initial_tests + 1,
         )
 
         for _ in range(num_tests):
