@@ -49,7 +49,7 @@ class InstrumentationLoader(SourceFileLoader):
         to_instrument = cast(CodeType, super().get_code(fullname))
         assert to_instrument, "Failed to get code object of module."
         # TODO(fk) apply different instrumentations here
-        if config.configuration.dynamic_constant_seeding:
+        if config.configuration.seeding.dynamic_constant_seeding:
             dynamic_seeding_instr = DynamicSeedingInstrumentation()
             to_instrument = dynamic_seeding_instr.instrument_module(to_instrument)
         instrumentation = BranchDistanceInstrumentation(self._tracer)
