@@ -147,6 +147,13 @@ class ExecutionTracer:
         """
         self._current_thread_ident = current
 
+    @property
+    def import_trace(self) -> ExecutionTrace:
+        """The trace that was generated when the SUT was imported."""
+        copied = ExecutionTrace()
+        copied.merge(self._import_trace)
+        return copied
+
     def get_known_data(self) -> KnownData:
         """Provide known data.
 
@@ -420,10 +427,14 @@ def _in(val1, val2) -> float:
     Returns:
         the distance
     """
-    # TODO(fk) iterate over elements and return smallest distance?
     if val1 in val2:
         return 0.0
-    return 1.0
+    # TODO(fk) maybe limit this to certain collections?
+    # Check only if collection size is within some range,
+    # otherwise the check might take very long.
+
+    # Use smallest distance to any element.
+    return min([_eq(val1, v) for v in val2] + [inf])
 
 
 def _nin(val1, val2) -> float:
