@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2020 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2021 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -18,11 +18,11 @@ class VariableReferenceImpl(vr.VariableReference):
     ) -> vr.VariableReference:
         return new_test_case.get_statement(
             self.get_statement_position() + offset
-        ).return_value
+        ).ret_val
 
     def get_statement_position(self) -> int:
         for idx, stmt in enumerate(self._test_case.statements):
-            if stmt.return_value is self:
+            if stmt.ret_val is self:
                 return idx
         raise Exception(
             "Variable reference is not declared in the test case in which it is used"
